@@ -26,7 +26,6 @@
 #include <QVBoxLayout>
 #include <QFormLayout>
 #include <kpushbutton.h>
-#include <q3whatsthis.h>
 #include <QLabel>
 #include <KLineEdit>
 
@@ -96,7 +95,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	titleButton = new KPushButton( parametersFrame );
 	titleButton->setObjectName( "titleButton" );
 	titleButton->setCheckable( true );
-	titleButton->setText( QString("%1 >>").arg(i18nc("@action:button Recipe title", "Title")) );
+	titleButton->setText( i18nc("@action:button Recipe title", "Title >>") );
 	parametersFrameLayout->addWidget( titleButton );
 	
 	titleFrame = new QFrame( parametersFrame );
@@ -125,7 +124,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	ingredientButton = new KPushButton( parametersFrame );
 	ingredientButton->setObjectName( "ingredientButton" );
 	ingredientButton->setCheckable( true );
-	ingredientButton->setText( QString("%1 >>").arg(i18nc("@action:button", "Ingredients")) );
+	ingredientButton->setText( i18nc("@action:button", "Ingredients >>") );
 	parametersFrameLayout->addWidget( ingredientButton );
 	
 	ingredientFrame = new QFrame( parametersFrame );
@@ -199,7 +198,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	authorsButton = new KPushButton( parametersFrame );
 	authorsButton->setObjectName( "authorsButton" );
 	authorsButton->setCheckable( true );
-	authorsButton->setText( QString("%1 >>").arg(i18nc("@action:button", "Authors")) );
+	authorsButton->setText( i18nc("@action:button", "Authors >>") );
 	parametersFrameLayout->addWidget( authorsButton );
 	
 	authorsFrame = new QFrame( parametersFrame );
@@ -236,7 +235,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	servingsButton = new KPushButton( parametersFrame );
 	servingsButton->setObjectName( "servingsButton" );
 	servingsButton->setCheckable( true );
-	servingsButton->setText( QString("%1 >>").arg(i18nc("@action:button", "Yield")) );
+	servingsButton->setText( i18nc("@action:button", "Yield >>") );
 	parametersFrameLayout->addWidget( servingsButton );
 	
 	servingsFrame = new QFrame( parametersFrame );
@@ -284,7 +283,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	prepTimeButton = new KPushButton( parametersFrame );
 	prepTimeButton->setObjectName( "prepTimeButton" );
 	prepTimeButton->setCheckable( true );
-	prepTimeButton->setText( QString("%1 >>").arg(i18nc( "@action:button", "Preparation Time")) );
+	prepTimeButton->setText( i18nc( "@action:button", "Preparation Time >>") );
 	parametersFrameLayout->addWidget( prepTimeButton );
 	
 	prepTimeFrame = new QFrame( parametersFrame );
@@ -329,7 +328,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	instructionsButton = new KPushButton( parametersFrame );
 	instructionsButton->setObjectName( "instructionsButton" );
 	instructionsButton->setCheckable( true );
-	instructionsButton->setText( QString("%1 >>").arg(i18nc( "@action:button", "Instructions")) );
+	instructionsButton->setText( i18nc( "@action:button", "Instructions >>") );
 	parametersFrameLayout->addWidget( instructionsButton );
 	
 	instructionsFrame = new QFrame( parametersFrame );
@@ -359,7 +358,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	metaDataButton = new KPushButton( parametersFrame );
 	metaDataButton->setObjectName( "metaDataButton" );
 	metaDataButton->setCheckable( true );
-	metaDataButton->setText( QString("%1 >>").arg(i18nc( "@label", "Meta Data")) );
+	metaDataButton->setText( i18nc( "@action:button", "Meta Data >>") );
 	parametersFrameLayout->addWidget( metaDataButton );
 	
 	metaDataFrame = new QFrame( parametersFrame );
@@ -412,7 +411,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	ratingsButton = new KPushButton( parametersFrame );
 	ratingsButton->setObjectName( "ratingsButton" );
 	ratingsButton->setCheckable( true );
-	ratingsButton->setText( QString("%1 >>").arg(i18nc("@action:button", "Ratings")) );
+	ratingsButton->setText( i18nc("@action:button", "Ratings >>") );
 	parametersFrameLayout->addWidget( ratingsButton );
 
 	ratingButtonGroup = new QGroupBox( parametersFrame );
@@ -583,15 +582,15 @@ AdvancedSearchDialog::AdvancedSearchDialog( QWidget *parent, RecipeDB *db ) : QW
 	connect( metaDataButton, SIGNAL( toggled( bool ) ), metaDataFrame, SLOT( setShown( bool ) ) );
 	connect( ratingsButton, SIGNAL( toggled( bool ) ), ratingButtonGroup, SLOT( setShown( bool ) ) );
 
-	connect( titleButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( ingredientButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( authorsButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( categoriesButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( servingsButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( prepTimeButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( instructionsButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( metaDataButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
-	connect( ratingsButton, SIGNAL( toggled( bool ) ), SLOT( buttonSwitched() ) );
+	connect( titleButton, SIGNAL( toggled( bool ) ), SLOT( titleButtonSwitched( bool ) ) );
+	connect( ingredientButton, SIGNAL( toggled( bool ) ), SLOT( ingredientButtonSwitched( bool ) ) );
+	connect( authorsButton, SIGNAL( toggled( bool ) ), SLOT( authorsButtonSwitched( bool ) ) );
+	connect( categoriesButton, SIGNAL( toggled( bool ) ), SLOT( categoriesButtonSwitched( bool ) ) );
+	connect( servingsButton, SIGNAL( toggled( bool ) ), SLOT( servingsButtonSwitched( bool ) ) );
+	connect( prepTimeButton, SIGNAL( toggled( bool ) ), SLOT( prepTimeButtonSwitched( bool ) ) );
+	connect( instructionsButton, SIGNAL( toggled( bool ) ), SLOT( instructionsButtonSwitched( bool ) ) );
+	connect( metaDataButton, SIGNAL( toggled( bool ) ), SLOT( metaDataButtonSwitched( bool ) ) );
+	connect( ratingsButton, SIGNAL( toggled( bool ) ), SLOT( ratingsButtonSwitched( bool ) ) );
 
 	connect( ratingAvgRadioButton, SIGNAL( clicked() ), this, SLOT( activateRatingOptionAvg() ) );
 	connect( criterionRadioButton, SIGNAL( clicked() ), this, SLOT( activateRatingOptionCriterion() ) );
@@ -629,6 +628,7 @@ void AdvancedSearchDialog::addAction( KAction * action )
 
 void AdvancedSearchDialog::showEvent( QShowEvent * event )
 {
+          Q_UNUSED(event);
 	actionHandler->selectionChangedSlot();
 }
 
@@ -697,17 +697,76 @@ void AdvancedSearchDialog::activateRatingOptionCriterion()
 	ratingAvgFrame->setEnabled( false );
 }
 
-void AdvancedSearchDialog::buttonSwitched()
+void AdvancedSearchDialog::titleButtonSwitched( bool checked )
 {
-	const QObject *sent = sender();
+	if ( checked )
+		titleButton->setText( i18nc("@action:button Recipe title", "Title <<") );
+	else
+		titleButton->setText( i18nc("@action:button Recipe title", "Title >>") );
+}
 
-	if ( sent->inherits("KPushButton") ) {
-		KPushButton *pushed = (KPushButton*) sent;
+void AdvancedSearchDialog::ingredientButtonSwitched( bool checked )
+{
+	if ( checked )
+		ingredientButton->setText( i18nc("@action:button", "Ingredients <<") );
+	else
+		ingredientButton->setText( i18nc("@action:button", "Ingredients >>") );
+}
 
-		//KDE4 port
-		QString suffix = ( pushed->isChecked() ) ? " <<" : " >>";
-		pushed->setText( pushed->text().left( pushed->text().length() - 3 ) + suffix );
-	}
+void AdvancedSearchDialog::authorsButtonSwitched( bool checked )
+{
+	if ( checked )
+		authorsButton->setText( i18nc("@action:button", "Authors <<") );
+	else
+		authorsButton->setText( i18nc("@action:button", "Authors >>") );
+}
+
+void AdvancedSearchDialog::categoriesButtonSwitched( bool checked )
+{
+	if ( checked )
+		categoriesButton->setText( i18nc( "@action:button", "Categories <<" ) );
+	else
+		categoriesButton->setText( i18nc( "@action:button", "Categories >>" ) );
+}
+
+void AdvancedSearchDialog::servingsButtonSwitched( bool checked )
+{
+	if ( checked )
+		servingsButton->setText( i18nc("@action:button", "Yield <<") );
+	else
+		servingsButton->setText( i18nc("@action:button", "Yield >>") );
+}
+
+void AdvancedSearchDialog::prepTimeButtonSwitched( bool checked )
+{
+	if ( checked )
+		prepTimeButton->setText( i18nc( "@action:button", "Preparation Time <<") );
+	else
+		prepTimeButton->setText( i18nc( "@action:button", "Preparation Time >>") );
+}
+
+void AdvancedSearchDialog::instructionsButtonSwitched( bool checked )
+{
+	if ( checked )
+		instructionsButton->setText( i18nc( "@action:button", "Instructions <<") );
+	else
+		instructionsButton->setText( i18nc( "@action:button", "Instructions >>") );
+}
+
+void AdvancedSearchDialog::metaDataButtonSwitched( bool checked )
+{
+	if ( checked )
+		metaDataButton->setText( i18nc( "@action:button", "Meta Data <<") );
+	else
+		metaDataButton->setText( i18nc( "@action:button", "Meta Data >>") );
+}
+
+void AdvancedSearchDialog::ratingsButtonSwitched( bool checked )
+{
+	if ( checked )
+		ratingsButton->setText( i18nc("@action:button", "Ratings <<") );
+	else
+		ratingsButton->setText( i18nc("@action:button", "Ratings >>") );
 }
 
 void AdvancedSearchDialog::search()
@@ -774,7 +833,7 @@ void AdvancedSearchDialog::search()
 	for ( QStringList::const_iterator author_it = items.constBegin(); author_it != items.constEnd(); ++author_it ) {
 		for ( RecipeList::iterator it = allRecipes.begin(); it != allRecipes.end(); ++it ) {
 			if ( ( *it ).authorList.findByName( QRegExp(*author_it, Qt::CaseInsensitive, QRegExp::Wildcard) ).id == -1 ) {
-				it = allRecipes.remove( it );
+				it = allRecipes.erase( it );
 				it--;
 			}
 		}
@@ -783,7 +842,7 @@ void AdvancedSearchDialog::search()
 	for ( QStringList::const_iterator author_it = items.constBegin(); author_it != items.constEnd(); ++author_it ) {
 		for ( RecipeList::iterator it = allRecipes.begin(); it != allRecipes.end(); ++it ) {
 			if ( ( *it ).authorList.findByName( QRegExp(*author_it, Qt::CaseInsensitive, QRegExp::Wildcard) ).id != -1 ) {
-				it = allRecipes.remove( it );
+				it = allRecipes.erase( it );
 				it--;
 			}
 		}
@@ -794,7 +853,7 @@ void AdvancedSearchDialog::search()
 	for ( QStringList::const_iterator cat_it = items.constBegin(); cat_it != items.constEnd(); ++cat_it ) {
 		for ( RecipeList::iterator it = allRecipes.begin(); it != allRecipes.end(); ++it ) {
 			if ( ( *it ).categoryList.findByName( QRegExp(*cat_it, Qt::CaseInsensitive, QRegExp::Wildcard) ).id == -1 ) {
-				it = allRecipes.remove( it );
+				it = allRecipes.erase( it );
 				it--;
 			}
 		}
@@ -803,7 +862,7 @@ void AdvancedSearchDialog::search()
 	for ( QStringList::const_iterator cat_it = items.constBegin(); cat_it != items.constEnd(); ++cat_it ) {
 		for ( RecipeList::iterator it = allRecipes.begin(); it != allRecipes.end(); ++it ) {
 			if ( ( *it ).categoryList.findByName( QRegExp(*cat_it, Qt::CaseInsensitive, QRegExp::Wildcard) ).id != -1 ) {
-				it = allRecipes.remove( it );
+				it = allRecipes.erase( it );
 				it--;
 			}
 		}
@@ -814,7 +873,7 @@ void AdvancedSearchDialog::search()
 	for ( QStringList::const_iterator ing_it = items.constBegin(); ing_it != items.constEnd(); ++ing_it ) {
 		for ( RecipeList::iterator it = allRecipes.begin(); it != allRecipes.end(); ++it ) {
 			if ( ( *it ).ingList.findByName( QRegExp(*ing_it, Qt::CaseInsensitive, QRegExp::Wildcard) ).ingredientID == -1 ) {
-				it = allRecipes.remove( it );
+				it = allRecipes.erase( it );
 				it--;
 			}
 		}
@@ -823,7 +882,7 @@ void AdvancedSearchDialog::search()
 	for ( QStringList::const_iterator ing_it = items.constBegin(); ing_it != items.constEnd(); ++ing_it ) {
 		for ( RecipeList::iterator it = allRecipes.begin(); it != allRecipes.end(); ++it ) {
 			if ( ( *it ).ingList.findByName( QRegExp(*ing_it, Qt::CaseInsensitive, QRegExp::Wildcard) ).ingredientID != -1 ) {
-				it = allRecipes.remove( it );
+				it = allRecipes.erase( it );
 				it--;
 			}
 		}
@@ -854,12 +913,12 @@ void AdvancedSearchDialog::search()
 
 				kDebug()<<"average for "<<(*recipe_it).title<<" "<<average;
 				if ( average < stars || average > stars + stars_offset ) {
-					recipe_it = allRecipes.remove( recipe_it );
+					recipe_it = allRecipes.erase( recipe_it );
 					recipe_it--;
 				}
 			}
 			else {
-				recipe_it = allRecipes.remove( recipe_it );
+				recipe_it = allRecipes.erase( recipe_it );
 				recipe_it--;
 			}
 		}
@@ -904,13 +963,13 @@ void AdvancedSearchDialog::search()
 					double average = (*sum_it)/(*count_it);
 
 					if ( average < stars || average > stars + stars_offset ) {
-						recipe_it = allRecipes.remove( recipe_it );
+						recipe_it = allRecipes.erase( recipe_it );
 						recipe_it--;
 						break;
 					}
 				}
 				else {
-					recipe_it = allRecipes.remove( recipe_it );
+					recipe_it = allRecipes.erase( recipe_it );
 					recipe_it--;
 					break;
 				}
